# Croqueta <img src="img/croqueta.png" alt="Croqueta Logo" width="60" height="60" style="vertical-align: middle;">



A library with all sorts of utils and handy functions for non-production code.



Installation
------------
```pip install croqueta```

